# libs
%define owfslibmajor 4
%define owfslibname %mklibname %{name} %{owfslibmajor}

%bcond_with php
%define php_extdir %{_libdir}/php/extensions/

Name:		owfs
Version:	3.2p4
Release:	%mkrel 2
Summary:	1-Wire Virtual File System
Group:		System/Networking

# some parts licensed differently, see http://owfs.org/index.php?page=license
License:	GPLv2
URL:		https://www.owfs.org/
Source0:	https://github.com/owfs/owfs/releases/download/v%{version}/%{name}-%{version}.tar.gz
#
# Fedora patches:
#
# install into 'vendor' perl directories; not suitable for upstream
Patch0:		owfs-0001-install-into-vendor-perl-directories.patch
#
# Mga patches:
#
# get php module to build and have the right name
Patch10:	owfs-2.9p5-php-module.patch

Requires: %{owfslibname} = %{version}-%{release}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
BuildRequires:	systemd
BuildRequires:	systemd-devel


%description
OWFS is a user-space virtual file-system providing access to 1-Wire networks.


%package -n %{owfslibname}
Summary: Core library providing base functions to other OWFS modules
Group: System/Libraries
BuildRequires: automake
BuildRequires: autoconf
BuildRequires: libtool
BuildRequires: libusb-devel

%description  -n %{owfslibname}
%{owfslibname} is a core library providing base functions to other OWFS modules.

%package capi
Summary: C-API to develop third-part applications which access 1-Wire networks
Group: Development/C
Requires: %{owfslibname} = %{version}-%{release}

%description capi
%{name}-capi library on top of libow providing an easy API to develop third-party
applications to access to 1-Wire networks.


%package devel
Summary: Files for development of OWFS applications
Group: Development/C
Requires: %{owfslibname} = %{version}

%description devel
This package contains the libraries and header files that are needed for
developing OWFS applications.


%package ownet
Summary: C-API to develop third-part applications which access 1-Wire networks
Group: Development/C
Requires: %{owfslibname} = %{version}-%{release}

%description ownet
%{name}-ownet library provides an easy API to develop third-party applications
to access to 1-Wire networks. It doesn't depend on owlib, and only supports
remote-server connections. This library doesn't include any 1-wire adapter
support, except server connections.


%package fs
Summary: Virtual file-system on top of %{owfslibname} providing access to 1-Wire networks
Group: System/Networking
Requires: %{owfslibname} = %{version}-%{release}
Requires: fuse >= 1.0
Requires: %{name}-server
BuildRequires: fuse-devel >= 1.0

%description fs
%{name}-fs is a virtual file-system on top of %{owfslibname} providing
access to 1-Wire networks.


%package httpd
Summary: HTTP daemon providing access to 1-Wire networks
Group: System/Networking
Requires: %{owfslibname} = %{version}-%{release}
Requires: %{name}-server

%description httpd
%{name}-httpd is a HTTP daemon on top of %{name} providing
access to 1-Wire networks.


%package ftpd
Summary: FTP daemon providing access to 1-Wire networks
Group: System/Networking
Requires: %{owfslibname} = %{version}-%{release}
Requires: %{name}-server

%description ftpd
%{name}-ftpd is a FTP daemon on top of %{name} providing access to 1-Wire networks.


%package server
Summary: Back-end server (daemon) for 1-wire control
Group: System/Networking
Requires: %{owfslibname} = %{version}-%{release}
Requires(pre): shadow-utils

%description server
%{name}-server is the back-end component of the OWFS 1-wire bus control system.
owserver arbitrates access to the bus from multiple client processes. The
physical bus is usually connected to a serial or USB port, and other processes
connect to owserver over network sockets (TCP port). Communication can be local
or over a network.


%package tap
Summary: Packet sniffer for the owserver protocol
Group: System/Networking
Requires: tcl >= 8.1
Requires: %{name}-tcl = %{version}-%{release}

%description tap
%{name}-tap is a packet sniffer for the owserver protocol


%package mon
Summary: Statistics and settings monitor for owserver
Group: System/Networking
Requires: tcl >= 8.1
Requires: %{name}-tcl = %{version}-%{release}

%description mon
%{name}-mon is a graphical monitor of owserver’s status


%if %{with php}
%package php
Summary: PHP interface for the 1-wire file-system
Group: System/Networking
Requires: %{owfslibname} = %{version}-%{release}
Requires: php >= 4.3.0
Requires: php-cli >= 4.3.0
BuildRequires: swig
BuildRequires: php-devel >= 4.3.0
BuildRequires: php-cli

%description php
%{name}-php is a php interface for the 1-wire file-system
%endif

%package tcl
Summary: Tcl interface for the 1-wire file-system
Group: System/Networking
Requires: %{owfslibname} = %{version}-%{release}
Requires: tcl >= 8.1
BuildRequires: tcl-devel >= 8.1

%description tcl
%{name}-tcl is a Tcl interface for the 1-wire file-system


%package shell
License: MIT
Summary: Light weight shell access to owserver and the 1-wire file-system
Group: System/Networking

%description shell
%{name}-shell is 5 small programs to easily access owserver (and thus
the 1-wire system) from shell scripts. owdir, owread, owwrite, owget
and owpresent.


%prep
%setup -q
%autopatch -p1

sed -i -e 's/) Makefile.PL/& INSTALLDIRS=vendor/' \
	module/swig/perl5/Makefile.am \
	module/ownet/perl5/Makefile.am


%build
./bootstrap
%configure --disable-owperl %{?!with_php:--disable-owphp} --disable-owpython
%make_build


%install
%make_install

# remove files that won't be packaged
find %{buildroot} -name "perllocal.pod" -delete
find %{buildroot} -name ".packlist" -print -delete
find %{buildroot} -name "*.la" -delete

%if %{with php}
# provide loading script as the man page suggests using it
cp -a module/swig/php/example/load_php_OW.php %{buildroot}%{_datarootdir}/php/
%endif

%pre server
# TODO: migrate to systemd-sysusers when guidelines are ready
getent group ow >/dev/null || groupadd -r ow
getent passwd ow >/dev/null || \
    useradd -r -g ow -d /var/empty -s /sbin/nologin \
    -c "1-wire file-system (OWFS) utilities account" ow
exit 0

%post fs
%_post_service owfs.service

%post httpd
%_post_service owhttpd.service

%post ftpd
%_post_service owftpd.service

%post server
%_post_service owserver.service


%preun fs
%_preun_service owfs.service

%preun httpd
%_preun_service owhttpd.service

%preun ftpd
%_preun_service owftpd.service

%preun server
%_preun_service owserver.service

%files -n %{owfslibname}
%doc README.md NEWS ChangeLog AUTHORS COPYING
%{_libdir}/libow-*.so.%{owfslibmajor}{,.*}
%{_mandir}/man3/*.3.*
%{_mandir}/man5/owfs.5.*
%{_mandir}/man5/owfs.conf.5.*


%files devel
%{_includedir}/owfs_config.h
%{_includedir}/owcapi.h
%{_includedir}/ownetapi.h
%{_libdir}/libow.so
%{_libdir}/libowcapi.so
%{_libdir}/libownet.so
%{_libdir}/pkgconfig/owcapi.pc
%{_mandir}/man?/*


%files capi
%{_libdir}/libowcapi-*.so*
%{_mandir}/man1/*owcapi.1.*


%files ownet
%{_libdir}/libownet-*.so*
%{_mandir}/man1/*ownet*.1.*


%files fs
%{_bindir}/owfs
%{_mandir}/man1/owfs.1.*
%{_unitdir}/owfs.service


%files httpd
%{_bindir}/owhttpd
%{_mandir}/man1/owhttpd.1.*
%{_unitdir}/owhttpd.service


%files shell
%{_bindir}/owdir
%{_bindir}/owexist
%{_bindir}/owread
%{_bindir}/owwrite
%{_bindir}/owget
%{_bindir}/owpresent
%{_bindir}/owusbprobe
%{_mandir}/man1/owshell.1.*
%{_mandir}/man1/owdir.1.*
%{_mandir}/man1/owread.1.*
%{_mandir}/man1/owget.1.*
%{_mandir}/man1/owpresent.1.*
%{_mandir}/man1/owwrite.1.*


%files ftpd
%{_bindir}/owftpd
%{_mandir}/man1/owftpd.1.*
%{_unitdir}/owftpd.service


%files server
%{_bindir}/owserver
%{_bindir}/owexternal
%{_mandir}/man1/owserver.1.*
%{_unitdir}/owserver.service
%{_unitdir}/owserver.socket


%files tap
%doc COPYING
%{_bindir}/owtap
%{_mandir}/man1/owtap.1.*


%files mon
%doc COPYING
%{_bindir}/owmon
%{_mandir}/man1/owmon.1.*


%if %{with php}
%files php
%{php_extdir}/libowphp.so
%{_datarootdir}/php/OWNet/ownet.php
%{_datarootdir}/php/load_php_OW.php
%endif

%files tcl
%dir %{_libdir}/tcl8.6/owtcl-*
%{_libdir}/tcl8.6/owtcl-*/*
%{_mandir}/mann/owtcl.n.*
%{_mandir}/mann/ow.n.*


%changelog
* Sat Jun 28 2025 umeabot <umeabot> 3.2p4-2.mga10
+ Revision: 2216618
- Mageia 10 Mass Rebuild

* Thu Dec 01 2022 danf <danf> 3.2p4-1.mga9
+ Revision: 1913947
- Update to ver. 3.2p4
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Aug 06 2020 joequant <joequant> 3.2p2-4.mga8
+ Revision: 1611617
- gcc10 build

* Thu Feb 20 2020 umeabot <umeabot> 3.2p2-3.mga8
+ Revision: 1546301
- Mageia 8 Mass Rebuild

* Sat Feb 01 2020 wally <wally> 3.2p2-2.mga8
+ Revision: 1486332
- drop python2 pkg
- replace deprecated %%configure2_5x

* Sat Sep 29 2018 daviddavid <daviddavid> 3.2p2-1.mga7
+ Revision: 1310897
- new version: 3.2p2
- now libmajor is 2
- add upstream patch to fix build with new glibc
- remove merged upstream patches
- rename owfs-python to python2-owfs
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Mon Jun 25 2018 wally <wally> 3.1p0-2.mga7
+ Revision: 1239606
- disable php support (doesn't build with php7)
- modernize provides filtering

* Fri Mar 18 2016 tv <tv> 3.1p0-1.mga6
+ Revision: 992756
- adjust file list
- BR systemd-devel so that build succeeds on BS too
- use upstream systemd stuff
- better fix for USB incluides
- BR libusb0.1-devel
- adjust file list
- fix major
- fix TCL path
- regenerate auto (hopefully fixing build)
- add build fix patches from FC
- new release
- disable underlinking
- kill inexistant option
+ luigiwalser <luigiwalser>
- rebuild with configure2_5x and make_install
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
+ daviddavid <daviddavid>
- rebuild for new tcl 8.6.4

* Wed Feb 25 2015 tmb <tmb> 2.9p5-5.mga5
+ Revision: 816992
- fix preun/post services

* Wed Oct 15 2014 umeabot <umeabot> 2.9p5-4.mga5
+ Revision: 745417
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.9p5-3.mga5
+ Revision: 727530
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.9p5-2.mga5
+ Revision: 683290
- Mageia 5 Mass Rebuild

* Sun Jul 06 2014 pterjan <pterjan> 2.9p5-1.mga5
+ Revision: 644072
- Add BuildRequires php-cli
- Provide load_php_OW.php script
- Don't own php extensions dir
- Get php module to build
- Update to 2.9p5
- Drop broken require on libusb,there is already an automatic one
- Rebuild for new Python

* Thu Dec 19 2013 tmb <tmb> 2.9p1-1.mga4
+ Revision: 558919
- add groups
- libify
- import from fedora


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.9p1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 09 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 2.9p1-4
- add BR: systemd

* Wed Jul 03 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 2.9p1-3
- include main COPYING in -tap and -mon

* Mon Jul 01 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 2.9p1-2
- deal with unused-direct-shlib-dependency

* Thu Jun 20 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 2.9p1-1
- update to 2.9p1, dropping merged patches
- remove perl-owfs bits from .spec, for now
- correct python _OW.so perms 0775 -> 0755

* Thu Jun 13 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 2.9p0-4
- furher fixes:
  - BR: python2-devel for -python; drop -devel req 
  - add tcl dep for owmon and owtap 

* Fri May 10 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 2.9p0-3
- use /run/owfs instead of /mnt/1wire
  (ref: https://lists.fedoraproject.org/pipermail/devel/2013-May/182420.html)

* Mon May 06 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 2.9p0-2
- fix issues:
  - add Require: python-devel to python subpackage
  - synchronise ldconfig requires with glibc provides

* Mon Mar 25 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 2.9p0-1
- initial package, based on work by Serg Oskin and Vadim Tkachenko
